<?php

$LANG = array(

'L_MENU'													=> 'Menu',
'L_UNKNOWN_ERROR'											=> 'Unknown error',
'L_CONFIRM_DELETE'											=> 'Confirm the deletion?',
'L_SAVE_FILE'												=> 'Save the file',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'File saved successfully',
'L_SAVE_FILE_ERROR'											=> 'Error while saving file',
'L_REPLY'													=> 'Reply',
'L_REPLY_TO'												=> 'Reply to',
'L_CANCEL'													=> 'Cancel',
'L_DELETE'													=> 'Delete',
'L_DELETE_FILE' 				    						=> 'Delete file',
'L_DELETE_FOLDER'				   							=> 'Delete folder',
'L_THUMBNAIL'												=> 'Thumbnail (optional)',
'L_THUMBNAIL_SELECTION'										=> 'Select image',
'L_THUMBNAIL_TITLE'											=> 'Image Title (optional)',
'L_THUMBNAIL_ALT'											=> 'Alternative text of the image (optional)',
'L_SAVE_SUCCESSFUL'											=> 'Data was succesfully saved',
'L_SAVE_ERR'												=> 'Error while saving data',
'L_NO_ENTRY'												=> 'No entry',
'L_ERR_USER_EMPTY'											=> 'Please enter a username',
'L_ERR_PASSWORD_EMPTY'										=> 'Please enter a password',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'Wrong or missing password',
'L_ERR_INVALID_EMAIL'										=> 'Invalid email adress',
'L_ERR_INVALID_SITE'										=> 'Wrong site url',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'Wrong article id !',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'new-category',
'L_DEFAULT_NEW_STATIC_URL'									=> 'new-page',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'new-article',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Post was succesfully created',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Post was succesfully updated',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Post was succesfully deleted',
'L_ARTICLE_SAVE_ERR'										=> 'Post couldn\'t be saved',
'L_ARTICLE_DELETE_ERR'										=> 'An error occured : post couldn\'t be deleted',
'L_ERR_UNKNOWN_COMMENT'										=> 'Selected comment no longer exists',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Comment was succesfully saved',
'L_COMMENT_UPDATE_ERR'										=> 'Error updating comment',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Comment was sucessfully deleted',
'L_COMMENT_DELETE_ERR'										=> 'An error occured in deletion of the comment',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Comment was sucessfully validated',
'L_COMMENT_VALIDATE_ERR'									=> 'An error occured in the validation',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Sucessfull moderation',
'L_COMMENT_MODERATE_ERR'									=> 'An error occured in the moderation',
'L_COMMENT_WRITTEN_BY'										=> 'Written by',
'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Coul\'t create the media folder for connected user',
'L_PLXMEDIAS_ROOT'											=> 'root',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Could\'t create folder',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'Folder succesfully created',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'This folder already exists',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Error during the folder deletion',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'Folder sucessfully deleted',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'The file type is not allowed',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'A file\'s size is bigger than',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Error while sending a file',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'File sent successfully',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Error while uploading files',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'Files sent successfully',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'Successfully removed files',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Error while deleting a file',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'File successfully deleted',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Error while deleting the file',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'Files sucessfully moved',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'File sucessfully moved',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'An error occured while moving the files',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'An error occured while moving the file',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Move',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Error while creating the thumbnail',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Error creating thumbnail',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Thumbnail successfully created',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Thumbnails created successfully',
'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'New article',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Invalid publishing date.',
'L_ERR_UNKNOWN_ARTICLE'										=> 'The article doesn\'t exist',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'You don\'t have permission to access this article!',
'L_BACK_TO_ARTICLES'										=> 'Back to articles',
'L_ARTICLE_EDITING'											=> 'Article editing',
'L_ARTICLE_TITLE'											=> 'Title',
'L_ARTICLE_LIST_AUTHORS'									=> 'Author',
'L_HEADLINE_FIELD'											=> 'Headline (optional)',
'L_CONTENT_FIELD'											=> 'Content',
'L_LINK_FIELD'												=> 'Link to article',
'L_LINK_ACCESS'												=> 'Go to article',
'L_LINK_VIEW'												=> 'view',
'L_ARTICLE_STATUS'											=> 'Status',
'L_DRAFT'													=> 'Draft',
'L_PUBLISHED'												=> 'Published',
'L_AWAITING'												=> 'Awaiting validation',
'L_ARTICLE_DATE'											=> 'Article date',
'L_NOW'														=> 'now',
'L_ARTICLE_CATEGORIES'										=> 'Categories',
'L_CATEGORY_HOME_PAGE'										=> 'Homepage',
'L_NEW_CATEGORY'											=> 'New category',
'L_ARTICLE_TAGS_FIELD'										=> 'Tags',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Separate tags with commas',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Tag list',
'L_NO_TAG'													=> 'No tag',
'L_ALLOW_COMMENTS'											=> 'Allow comments',
'L_ARTICLE_URL_FIELD'										=> 'Url',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'URL field auto-fills when the article is created',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Manage comments',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Manage comments on this article',
'L_ARTICLE_NEW_COMMENT'										=> 'Write a comment',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Write a comment about this article',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Delete this article?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Preview',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Save draft',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Publish',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Submit for validation',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Switch offline',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Save',
'L_CATEGORY_ADD_BUTTON'										=> 'Add',
'L_ARTICLE_META_DESCRIPTION'								=> '"Description" Meta tag content  (optional)',
'L_ARTICLE_META_KEYWORDS'									=> '"Keywords" Meta tag content (optional)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Title tag contents (optional)',
'L_ARTICLE_CHAPO_HIDE'										=> 'hide',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'display',
'L_ARTICLE'													=> 'article',
'L_ARTICLE_ID'												=> 'Ident',
'L_AUTH_PAGE_TITLE'											=> 'Authentication page',
'L_LOGOUT_SUCCESSFUL'										=> 'Logout successful',
'L_LOGIN_PAGE'												=> 'Login to administration',
'L_AUTH_LOGIN_FIELD'										=> 'Login',
'L_AUTH_PASSWORD_FIELD'										=> 'Password',
'L_SUBMIT_BUTTON'											=> 'Submit',
'L_ERR_WRONG_PASSWORD'										=> 'Incorrect login or password',
'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
'L_CAT_TITLE'												=> 'Category Manager',
'L_CAT_LIST_ID'												=> 'ID',
'L_CAT_LIST_ACTIVE'											=> 'Active',
'L_CAT_LIST_NAME'											=> 'Category name',
'L_CAT_LIST_URL'											=> 'Url',
'L_CAT_LIST_SORT'											=> 'Article sorting',
'L_CAT_LIST_BYPAGE'											=> 'Articles/page',
'L_CAT_LIST_ORDER'											=> 'Rank',
'L_CAT_LIST_MENU'											=> 'Menu',
'L_CATEGORY'												=> 'Category',
'L_DISPLAY'													=> 'Display',
'L_HIDE'													=> 'Hide',
'L_OPTIONS'													=> 'Options',
'L_SORT_ASCENDING_DATE'										=> 'ascending date',
'L_SORT_DESCENDING_DATE'									=> 'descending date',
'L_SORT_ALPHABETICAL'										=> 'alphabetical',
'L_OK'														=> 'Ok',
'L_YES'														=> 'Yes',
'L_NO'														=> 'No',
'L_NONE1'													=> 'none',
'L_NONE2'													=> 'none',
'L_FOR_SELECTION'											=> 'Selected items...',
'L_CAT_APPLY_BUTTON'										=> 'Change categories list',
'L_CAT_UNKNOWN'												=> 'Unknown category',
'L_EDITCAT_PAGE_TITLE'										=> 'Edit category options',
'L_EDITCAT_DESCRIPTION'										=> 'Description',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Show articles on the homepage',
'L_EDITCAT_TEMPLATE'										=> 'Template',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Back to categories',
'L_EDITCAT_UPDATE'											=> 'Update this category',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Title tag contents (optional)',
'L_EDITCAT_META_DESCRIPTION'								=> '"Description" Meta tag content  (optional)',
'L_EDITCAT_META_KEYWORDS'									=> '"Keywords" Meta tag content  (optional)',
'L_COMMENT_ORPHAN'											=> 'no article',
'L_COMMENT_ORPHAN_STATUS'									=> 'not displayed (we advise you to delete this comment)',
'L_COMMENT_ARTICLE_LINKED'									=> 'Article',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Article linked to this comment',
'L_COMMENT_OFFLINE'											=> 'offline',
'L_COMMENT_ONLINE'											=> 'online',
'L_COMMENT_ONLINE_TITLE'									=> 'Published comments',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Back to this article\'s comments',
'L_BACK_TO_COMMENTS'										=> 'Back to comments',
'L_COMMENT_EDITING'											=> 'Comment edit',
'L_COMMENT_AUTHOR_FIELD'									=> 'Author',
'L_COMMENT_TYPE_FIELD'										=> 'Comment type',
'L_COMMENT_DATE_FIELD'										=> 'Date and time of publication',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'Site',
'L_COMMENT_EMAIL_FIELD'										=> 'E-mail',
'L_COMMENT_STATUS_FIELD'									=> 'Status',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Linked article',
'L_COMMENT_ARTICLE_FIELD'									=> 'Comments',
'L_COMMENT_DELETE_CONFIRM'									=> 'Delete this comment?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Confirm publication',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Switch offline',
'L_COMMENT_ANSWER_BUTTON'									=> 'Reply to this comment',
'L_COMMENT_UPDATE_BUTTON'									=> 'Update',
'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'The comment you are trying to reply to no longer exists!',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'Comment is offline, you can\'t answer it!',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'The article doesn\'t exist and you can\'t comment it!',
'L_ERR_CREATING_COMMENT'									=> 'An error occured while creating the comment',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'Comment succesfully created',
'L_CREATE_NEW_COMMENT'										=> 'Write a comment',
'L_COMMENT_SAVE_BUTTON'										=> 'Save',
'L_ARTICLE_COMMENTS_LIST'									=> 'Comments for this article (from most recent to the oldest)',
'L_COMMENT_ANSWER_TITLE'									=> 'Reply to this comment',
'L_COMMENT_ANSWER'											=> 'Answer',
'L_COMMENTS_ARTICLE_SCOPE'									=> 'Article',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'entire site',
'L_COMMENTS_OFFLINE_LIST'									=> 'Comments awaiting moderation',
'L_COMMENTS_LIST_DATE'										=> 'Date',
'L_COMMENTS_LIST_AUTHOR'									=> 'Author',
'L_COMMENTS_LIST_MESSAGE'									=> 'Message',
'L_COMMENTS_LIST_ACTION'									=> 'Action',
'L_COMMENT_EDIT'											=> 'Edit',
'L_COMMENT_EDIT_TITLE'										=> 'Edit this comment',
'L_COMMENT_DELETE'											=> 'Delete',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'Rss feed for offline comments',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Offline comments',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'Rss feed for online comments',
'L_COMMENT_ONLINE_FEEDS'									=> 'Online comments',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Private feeds',
'L_COMMENTS_ONLINE_LIST'									=> 'List of published reviews',
'L_COMMENTS_ALL_LIST'										=> 'Comments List',
'L_COMMENT_SET_ONLINE'										=> 'Set online',
'L_COMMENT_SET_OFFLINE'										=> 'Set Offline',
'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Write a new comment for this article',
'L_COMMENT_NEW_COMMENT'										=> 'Write a new comment',
'L_ARTICLES_FILTER_BUTTON'									=> 'Filter',
'L_CATEGORIES_TABLE'										=> 'Categories',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Spectific categories',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'All articles',
'L_ARTICLES_LIST'											=> 'Article list',
'L_ARTICLE_LIST_DATE'										=> 'Date',
'L_ARTICLE_LIST_TITLE'										=> 'Title',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Category',
'L_ARTICLE_LIST_NBCOMS'										=> 'N° coms',
'L_ARTICLE_LIST_AUTHOR'										=> 'Author',
'L_ARTICLE_LIST_ACTION'										=> 'Action',
'L_CATEGORY_HOME'											=> 'Home',
'L_CATEGORY_DRAFT'											=> 'Draft',
'L_ARTICLE_VIEW'											=> 'View',
'L_ARTICLE_VIEW_TITLE'										=> 'View this article online',
'L_ARTICLE_EDIT'											=> 'Edit',
'L_ARTICLE_EDIT_TITLE'										=> 'Edit this article',
'L_NEW_COMMENTS_TITLE'										=> 'Comments awaiting moderation',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Published comments',
'L_NO_ARTICLE'												=> 'No article',
'L_ARTICLES_SEARCH_BUTTON'									=> 'Search',
'L_ARTICLES_ALL_CATEGORIES'									=> 'All Categories ...',
'L_ALL'														=> 'All',
'L_ALL_PUBLISHED'											=> 'Published',
'L_ALL_DRAFTS'												=> 'Drafts',
'L_ALL_AWAITING_MODERATION'									=> 'Awaiting validation',
'L_MEDIAS_DELETE_FOLDER'									=> 'Delete folder',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Delete folder %s and its content ?',
'L_MEDIAS_NO_FILE'											=> 'No file',
'L_MEDIAS_FILENAME'											=> 'File name',
'L_MEDIAS_ADD_FILE'											=> 'Add file',
'L_MEDIAS_BACK'												=> 'Back',
'L_MEDIAS_TITLE'											=> 'Media manager',
'L_MEDIAS_IMAGES'											=> 'Pictures',
'L_MEDIAS_DOCUMENTS'										=> 'Documents',
'L_MEDIAS_CREATE_FOLDER'									=> 'Create folder',
'L_MEDIAS_SUBMIT_FILE'										=> 'Send',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Maximum file size',
'L_MEDIAS_DIRECTORY'										=> 'Location',
'L_MEDIAS_FOLDER'											=> 'File',
'L_MEDIAS_NEW_FOLDER'										=> 'New Folder',
'L_MEDIAS_FILESIZE'											=> 'Size',
'L_MEDIAS_DATE'												=> 'Date',
'L_MEDIAS_DIMENSIONS'										=> 'Dimensions',
'L_MEDIAS_RESIZE'											=> 'Resize Images',
'L_MEDIAS_RESIZE_NO'										=> 'Original Size',
'L_MEDIAS_THUMBS'											=> 'Create thumbnails',
'L_MEDIAS_THUMBS_NONE'										=> 'No thumbnail',
'L_MEDIAS_MODIFY'											=> 'Edit',
'L_MEDIAS_THUMB'											=> 'Thumbnail',
'L_MEDIAS_EXTENSION'										=> 'Extension',
'L_MEDIAS_ADD'												=> 'Add',
'L_MEDIAS_ALIGNMENT'										=> 'Alignment',
'L_MEDIAS_ALIGN_NONE'										=> 'None',
'L_MEDIAS_ALIGN_LEFT'										=> 'Left',
'L_MEDIAS_ALIGN_CENTER'										=> 'Center',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Right',
'L_MEDIAS_RECREATE_THUMB'									=> 'Recreate thumbnail',
'L_CONFIG_VIEW_FIELD'										=> 'Display preferences',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Skin',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Edit theme files',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Edit theme files',
'L_CONFIG_VIEW_SORT'										=> 'Sorting articles',
'L_CONFIG_VIEW_BYPAGE'										=> 'Articles per page',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Articles per page in archives',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Articles per page in administration',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Sorting comments',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Comments per page in administraton',
'L_CONFIG_VIEW_IMAGES'										=> 'Image Size (width x height)',
'L_CONFIG_VIEW_THUMBS'										=> 'Thumbnails size (width x height)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'Use a static page as Homepage',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Warning: this page is inactive',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Download themes at <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'N° of Articles or comments in the Rss feed',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Only display headlines in the Rss article feed',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Headline field is empty, content is displayed instead',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Signature used in the end of every Rss feed\'s article',
'L_CONFIG_VIEW_UPDATE'										=> 'Save display settings',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Display categories without article',
'L_CONFIG_HOMETEMPLATE'										=> 'Template of the homepage',
'L_CONFIG_ADVANCED_DESC'									=> 'Advanced configuration',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Enable url rewriting',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Warning: a .htaccess file already exists at your PluXml\'s installation root. Activating url rewriting will overwrite this file',
'L_CONFIG_ADVANCED_GZIP'									=> 'Enable GZIP compression',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Makes it possible to compress pages to save bandwidth, but could increase CPU usage',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Enable anti spam-capcha',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Administration key (private URLs)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Leave this field empty to rebuild key',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Use separate medias folders for every user',
'L_HELP_SLASH_END'											=> 'Don\'t forget the slash at the end',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Medias (folder) location',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Articles (folder) location',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Comments (folder) location',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Static page (folder) location',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Themes (folder) location',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Plugins (folder) location',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Configuration files (folder) location',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Save advanced configuration',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Location and name of custom css file of the administration area (optional)',
'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Basic configuration',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Site title',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Subtitle / Site description',
'L_CONFIG_BASE_URL_HELP'									=> 'Don\'t forget the slash at the end',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Default site language',
'L_CONFIG_BASE_TIMEZONE'									=> 'Time Zone',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Allow comments',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Moderate comments when created',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'Moderate articles for Editor and Publisher profiles',
'L_CONFIG_BASE_UPDATE'										=> 'Save basic configuration',
'L_CONFIG_META_DESCRIPTION'									=> 'Content of "description" meta tag (optional)',
'L_CONFIG_META_KEYWORDS'									=> 'Content of "keywords" meta tag (optional)',
'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'There is no such theme!',
'L_CONFIG_EDITTPL_TITLE'									=> 'Theme edit',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Choose file to edit:',
'L_CONFIG_EDITTPL_LOAD'										=> 'Load',
'L_CONFIG_INFOS_TITLE'										=> 'Information about PluXml',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Information about your PluXml installation, can be useful to repair it if needed.',
'L_CONFIG_INFOS_NB_CATS'									=> 'N° of categories :',
'L_CONFIG_INFOS_NB_STATICS'									=> 'N° of static pages :',
'L_CONFIG_INFOS_WRITER'										=> 'N° of users in session :',
'L_PLUXML_CHECK_VERSION'									=> 'Checking version number on the official PluXml.org site',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Can\'t check for updates as long as \'allow_url_fopen\' is disabled on this system',
'L_PLUXML_UPDATE_ERR'										=> 'Update check failed for an unknown reason',
'L_PLUXML_UPTODATE'											=> 'You are using PluXml\'s last version',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'A new PluXml version is available ! You can download it from',
'L_CONFIG_USERS_TITLE'										=> 'Manage users',
'L_CONFIG_USER'												=> 'User',
'L_CONFIG_USERS_ID'											=> 'User ID',
'L_CONFIG_USERS_ACTIVE'										=> 'Active',
'L_CONFIG_USERS_ACTION'										=> 'Action',
'L_CONFIG_USERS_NEW'										=> 'New user',
'L_CONFIG_USERS_UPDATE'										=> 'Modify the users\' list',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'Login ID already used',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Username already in use',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Category name already used',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Title already used',
'L_BACK_TO_PLUGINS'											=> 'Back to plugins\' page',
'L_NO_PLUGIN'												=> 'No plugin',
'L_PLUGIN_NO_CONFIG'										=> 'Not configured plugin',
'L_PLUGINS_CSS'												=> 'Css code',
'L_PLUGINS_CSS_TITLE'										=> 'Edit the css code of the plugin',
'L_CONTENT_FIELD_FRONTEND'									=> 'Css file content site',
'L_CONTENT_FIELD_BACKEND'									=> 'Css file content administrator',
'L_PLUGINS_TITLE'											=> 'Manage plugins',
'L_PLUGINS_VERSION'											=> 'Version',
'L_PLUGINS_AUTHOR'											=> 'Author',
'L_PLUGINS_ACTIVATE'										=> 'Enable',
'L_PLUGINS_DEACTIVATE'										=> 'Disable',
'L_PLUGINS_DELETE'											=> 'Delete',
'L_PLUGINS_DELETE_ERROR'									=> 'An error occured while deleting',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Successfull deletion',
'L_PLUGINS_CONFIG'											=> 'Configuration',
'L_PLUGINS_CONFIG_TITLE'									=> 'Plugin\'s configuration',
'L_PLUGINS_REQUIREMENTS'									=> 'Requirements',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Available and active plugins to activate this one',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'None',
'L_PLUGINS_ALPHA_SORT'										=> 'Sort alphabetically plugins',
'L_PLUGINS_LOADING_SORT'									=> 'Loading order',
'L_PLUGINS_ACTION'											=> 'Action',
'L_PLUGINS_APPLY_BUTTON'									=> 'Modify the plugins list',
'L_PLUGINS_ACTIVE_LIST'										=> 'Active plugins',
'L_PLUGINS_INACTIVE_LIST'									=> 'Inactive plugins',
'L_PROFIL_EDIT_TITLE'										=> 'Profile edit',
'L_PROFIL'													=> 'Profile',
'L_PROFIL_LOGIN'											=> 'Login',
'L_PROFIL_USER'												=> 'Username',
'L_PROFIL_MAIL'												=> 'Email address',
'L_PROFIL_ADMIN_LANG'										=> 'Language for administration',
'L_PROFIL_INFOS'											=> 'Information',
'L_PROFIL_UPDATE'											=> 'Save profile',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Change password',
'L_PROFIL_PASSWORD'											=> 'Password',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Confirm password',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Change password',
'L_STATIC_BACK_TO_PAGE'										=> 'Back to static page list',
'L_STATIC_UNKNOWN_PAGE'										=> 'This static page doesn\'t exist!',
'L_STATIC_TITLE'											=> 'Edit static page\'s source code',
'L_STATIC_VIEW_PAGE'										=> 'View page',
'L_STATIC_ON_SITE'											=> 'on site',
'L_STATIC_UPDATE'											=> 'Save this page',
'L_STATIC_TITLE_HTMLTAG'									=> 'Title tag contents (optional)',
'L_STATIC_META_DESCRIPTION'									=> 'Meta tag "description" content for this static page (optional)',
'L_STATIC_META_KEYWORDS'									=> 'Meta tag "keywords" content for this static page (optional)',
'L_STATICS_PAGE_TITLE'										=> 'Create and edit static pages',
'L_STATICS_ID'												=> 'ID',
'L_STATICS_GROUP'											=> 'Group',
'L_STATICS_TITLE'											=> 'Title',
'L_STATICS_URL'												=> 'Url',
'L_STATICS_ACTIVE'											=> 'Active',
'L_STATICS_ORDER'											=> 'Rank',
'L_STATICS_MENU'											=> 'Menu',
'L_STATICS_ACTION'											=> 'Action',
'L_STATICS_TEMPLATE_FIELD'									=> 'Template',
'L_STATICS_PAGE_HOME'										=> 'Set as Homepage',
'L_STATICS_HOME_PAGE'										=> 'Homepage',
'L_PAGE'													=> 'Page',
'L_VIEW'													=> 'See',
'L_STATICS_SRC_TITLE'										=> 'Edit source code for this page',
'L_STATICS_SRC'												=> 'Edit',
'L_STATICS_NEW_PAGE'										=> 'New page',
'L_STATICS_UPDATE'											=> 'Modify static page list',
'L_PROFIL_ADMIN'											=> 'Administrator',
'L_PROFIL_MANAGER'											=> 'Manager',
'L_PROFIL_MODERATOR'										=> 'Moderator',
'L_PROFIL_EDITOR'											=> 'Editor',
'L_PROFIL_WRITER'											=> 'Writer',
'L_ADMIN'													=> '- Administration',
'L_LOGIN'													=> 'Connected as',
'L_ADMIN_LOGOUT'											=> 'Disconnect',
'L_ADMIN_LOGOUT_TITLE'										=> 'Leave administrator\'s session',
'L_BACK_TO_SITE'											=> 'Home',
'L_BACK_TO_SITE_TITLE'										=> 'Back to homepage',
'L_BACK_TO_BLOG'											=> 'Blog',
'L_BACK_TO_BLOG_TITLE'										=> 'Back to blog',
'L_MENU_ARTICLES'											=> 'Articles',
'L_MENU_ARTICLES_TITLE'										=> 'List or Edit Articles',
'L_MENU_NEW_ARTICLES'										=> 'New article',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'New article',
'L_MENU_STATICS_TITLE'										=> 'List or Edit Static pages',
'L_MENU_STATICS'											=> 'Static pages',
'L_MENU_COMMENTS_TITLE'										=> 'List or Edit Comments',
'L_MENU_COMMENTS'											=> 'Comments',
'L_MENU_MEDIAS_TITLE'										=> 'Upload and insert media',
'L_MENU_MEDIAS'												=> 'Media',
'L_MENU_CATEGORIES_TITLE'									=> 'Create, manage, edit categories',
'L_MENU_CATEGORIES'											=> 'Categories',
'L_MENU_CONFIG_TITLE'										=> 'Configure PluXml',
'L_MENU_CONFIG'												=> 'Parameters',
'L_MENU_PROFIL_TITLE'										=> 'Manage your user profiles',
'L_MENU_PROFIL'												=> 'Profile',
'L_WARNING_INSTALLATION_FILE'								=> 'install.php file can still be found at your PluXml root.<br />For security reasons, it is strongly recommended to delete it.',
'L_USER_UNKNOWN'											=> 'Unknown user',
'L_USER_LANG'												=> 'Language used in administration',
'L_USER_MAIL'												=> 'Email adress',
'L_USER_INFOS'												=> 'Information',
'L_USER_UPDATE'												=> 'Update this user',
'L_USER_PAGE_TITLE'											=> 'Edit user options',
'L_USER_BACK_TO_PAGE'										=> 'Back to users\' list',
'L_MENU_CONFIG_BASE_TITLE'									=> 'Edit basic PluXml configuration',
'L_MENU_CONFIG_BASE'										=> 'Basic configuration',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'Change your PluXml\'s display settings',
'L_MENU_CONFIG_VIEW'										=> 'Display settings',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Manage user accounts on your PluXml',
'L_MENU_CONFIG_USERS'										=> 'User accounts',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Edit advanced configuration on your PluXml',
'L_MENU_CONFIG_ADVANCED'									=> 'Advanced configuration',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Information about your PluXml',
'L_MENU_CONFIG_INFOS'										=> 'Information',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Manage plugins',
'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Url already in use. Please change the value of the field \'Url\'',
'L_THEMES'													=> 'Themes',
'L_THEMES_TITLE'											=> 'Manage themes',
'L_HELP'													=> 'Help',
'L_HELP_TITLE'												=> 'See help',
'L_BACK_TO_THEMES'											=> 'Back to themes',
'L_ERR_INVALID_DATE_CREATION'								=> 'Invalid creation date',
'L_ERR_INVALID_DATE_UPDATE'									=> 'Invalid date updated',
);
?>
